@@ -1,7 +1,7 @@
 #![deny(missing_debug_implementations)]
-#![deny(missing_crate_level_docs)]
 #![deny(missing_copy_implementations)]
 #![deny(missing_docs)]
+#![deny(rustdoc::missing_crate_level_docs)]
 #![doc = include_str!("../readme.md")]
 #![doc(html_logo_url = "https://upload.wikimedia.org/wikipedia/commons/d/d5/Tailwind_CSS_Logo.svg")]
 #![doc(
